.. _api_geometry_box:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Box
==========================

.. autoclass:: Box
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: